A Plan is the set of file operations a generator wants to perform. Building the plan
is pure (no I/O), which makes generators easy to test and makes --dry-run trivial: we
simply render the plan instead of applying it.
Structs
Enums
- OpKind
- What a single file operation intends to do.